@@ -1,7 +1,7 @@
 package Test::SQL::Schema::Versioned;
 
-our $DATE = '2015-04-24'; # DATE
-our $VERSION = '0.17'; # VERSION
+our $DATE = '2015-04-29'; # DATE
+our $VERSION = '0.18'; # VERSION
 
 use 5.010001;
 use strict;
@@ -36,7 +36,7 @@ sub sql_schema_spec_ok {
             lives_ok {
                 my $res = create_or_update_db_schema(dbh=>$dbh1, spec=>$spec);
                 is($res->[0], 200, 'create/update status') or diag explain $res;
-            };
+            } "create latest v";
         };
 
         my $dbh2;
@@ -52,7 +52,7 @@ sub sql_schema_spec_ok {
             lives_ok {
                 my $res = create_or_update_db_schema(dbh=>$dbh2, spec=>$spec);
                 is($res->[0], 200, 'create/update status') or diag explain $res;
-            };
+            } "upgrade from v1 to latest";
         } if $spec->{latest_v} > 1;
 
         my $diff = diff_db_schema($dbh1, $dbh2);
@@ -76,7 +76,7 @@ Test::SQL::Schema::Versioned - Test SQL::Schema::Versioned spec
 
 =head1 VERSION
 
-This document describes version 0.17 of Test::SQL::Schema::Versioned (from Perl distribution SQL-Schema-Versioned), released on 2015-04-24.
+This document describes version 0.18 of Test::SQL::Schema::Versioned (from Perl distribution SQL-Schema-Versioned), released on 2015-04-29.
 
 =head1 FUNCTIONS
 
